@@ -52,9 +52,9 @@ Ogre-dependent is in the visualization/logging routines and the use of the Timer
 #   define OgreProfileGroup( a, g ) Ogre::Profile OGRE_TOKEN_PASTE(_OgreProfileInstance, __LINE__) ( (a), (g) )
 #   define OgreProfileBeginGroup( a, g ) Ogre::Profiler::getSingleton().beginProfile( (a), (g) )
 #   define OgreProfileEndGroup( a, g ) Ogre::Profiler::getSingleton().endProfile( (a), (g) )
-#   define OgreProfileBeginGPUEvent( g ) Ogre::Profiler::getSingleton().beginGPUEvent(g)
-#   define OgreProfileEndGPUEvent( g ) Ogre::Profiler::getSingleton().endGPUEvent(g)
-#   define OgreProfileMarkGPUEvent( e ) Ogre::Profiler::getSingleton().markGPUEvent(e)
+#   define OgreProfileBeginGPUEvent( g ) Ogre::Root::getSingleton().getRenderSystem()->beginProfileEvent(g)
+#   define OgreProfileEndGPUEvent( g ) Ogre::Root::getSingleton().getRenderSystem()->endProfileEvent()
+#   define OgreProfileMarkGPUEvent( e ) Ogre::Root::getSingleton().getRenderSystem()->markProfileEvent(e)
 #else
 #   define OgreProfile( a )
 #   define OgreProfileBegin( a )
@@ -221,11 +221,11 @@ namespace Ogre {
 
     /** The profiler allows you to measure the performance of your code
 
-            Do not create profiles directly from this unless you want a profile to last
-            outside of its scope (i.e. the main game loop). For most cases, use the macro
-            OgreProfile(name) and braces to limit the scope. You must enable the Profile
-            before you can used it with setEnabled(true). If you want to disable profiling
-            in Ogre, simply set the macro OGRE_PROFILING to 0.
+        Do not create profiles directly from this unless you want a profile to last
+        outside of its scope (i.e. the main game loop). For most cases, use the macro
+        OgreProfile(name) and braces to limit the scope. You must enable the Profile
+        before you can used it with setEnabled(true). If you want to disable profiling
+        in Ogre, simply set the macro OGRE_PROFILING to 0.
         @author Amit Mathew (amitmathew (at) yahoo (dot) com)
         @todo resolve artificial cap on number of profiles displayed
         @todo fix display ordering of profiles not called every frame
@@ -275,21 +275,6 @@ namespace Ogre {
             */
             void endProfile(const String& profileName, uint32 groupID = (uint32)OGREPROF_USER_DEFAULT);
 
-            /** Mark the beginning of a GPU event group
-             @remarks Can be safely called in the middle of the profile.
-             */
-            void beginGPUEvent(const String& event);
-
-            /** Mark the end of a GPU event group
-             @remarks Can be safely called in the middle of the profile.
-             */
-            void endGPUEvent(const String& event);
-
-            /** Mark a specific, ungrouped, GPU event
-             @remarks Can be safely called in the middle of the profile.
-             */
-            void markGPUEvent(const String& event);
-
             /** Sets whether this profiler is enabled. Only takes effect after the
                 the frame has ended.
                 @remarks When this is called the first time with the parameter true,
@@ -444,12 +429,12 @@ namespace Ogre {
 
     /** An individual profile that will be processed by the Profiler
 
-            Use the macro OgreProfile(name) instead of instantiating this profile directly
+        Use the macro OgreProfile(name) instead of instantiating this profile directly
 
-            We use this Profile to allow scoping rules to signify the beginning and end of
-            the profile. Use the Profiler singleton (through the macro OgreProfileBegin(name)
-            and OgreProfileEnd(name)) directly if you want a profile to last
-            outside of a scope (i.e. the main game loop).
+        We use this Profile to allow scoping rules to signify the beginning and end of
+        the profile. Use the Profiler singleton (through the macro OgreProfileBegin(name)
+        and OgreProfileEnd(name)) directly if you want a profile to last
+        outside of a scope (i.e. the main game loop).
         @author Amit Mathew (amitmathew (at) yahoo (dot) com)
     */
     class Profile : public ProfilerAlloc
