@@ -694,6 +694,7 @@ namespace Ogre
             ID_3D,
             ID_CUBIC,
             ID_2DARRAY,
+            ID_2DMS,
             ID_UNLIMITED,
             ID_ALPHA,
             ID_GAMMA,
@@ -863,6 +864,7 @@ namespace Ogre
         ID_TASK_PROGRAM,
         ID_TASK_PROGRAM_REF,
         ID_FSAA,
+        ID_USE_LINEAR_COLOURS,
         ID_END_BUILTIN_IDS
     };
     /** @} */
