@@ -32,10 +32,6 @@ THE SOFTWARE.
 #include "OgrePrerequisites.h"
 #include "OgreHeaderPrefix.h"
 
-#ifndef OGRE_SERIALIZER_VALIDATE_CHUNKSIZE
-#define OGRE_SERIALIZER_VALIDATE_CHUNKSIZE OGRE_DEBUG_MODE
-#endif
-
 namespace Ogre {
 
     /** \addtogroup Core
@@ -104,7 +100,6 @@ namespace Ogre {
         void readObject(const DataStreamPtr& stream, Quaternion& pDest);
 
         static String readString(const DataStreamPtr& stream);
-        OGRE_DEPRECATED static String readString(const DataStreamPtr& stream, size_t numChars);
 
         void flipToLittleEndian(void* pData, size_t size, size_t count = 1);
         void flipFromLittleEndian(void* pData, size_t size, size_t count = 1);
@@ -114,11 +109,11 @@ namespace Ogre {
         /// Determine the endianness to write with based on option
         void determineEndianness(Endian requestedEndian);
 
-#if OGRE_SERIALIZER_VALIDATE_CHUNKSIZE
+        // OGRE_SERIALIZER_VALIDATE_CHUNKSIZE
         typedef std::vector<size_t> ChunkSizeStack;
         ChunkSizeStack mChunkSizeStack;
         bool mReportChunkErrors;
-#endif
+
         void pushInnerChunk(const DataStreamPtr& stream);
         void popInnerChunk(const DataStreamPtr& stream);
         void backpedalChunkHeader(const DataStreamPtr& stream);
