@@ -42,24 +42,15 @@ namespace Ogre {
     /** \addtogroup Scene
     *  @{
     */
-    /** Pre-transforms and batches up meshes for efficient use as static
+    /** Pre-transforms and batches up meshes on the CPU for efficient use as static
         geometry in a scene.
 
-        Modern graphics cards (GPUs) prefer to receive geometry in large
-        batches. It is orders of magnitude faster to render 10 batches
-        of 10,000 triangles than it is to render 10,000 batches of 10 
-        triangles, even though both result in the same number of on-screen
-        triangles.
-    @par
-        Therefore it is important when you are rendering a lot of geometry to 
-        batch things up into as few rendering calls as possible. This
-        class allows you to build a batched object from a series of entities 
-        in order to benefit from this behaviour.
+        This class allows you to build a batched object from a series of entities.
         Batching has implications of it's own though:
-        @li Batched geometry cannot be subdivided; that means that the whole
+        - Batched geometry cannot be subdivided; that means that the whole
             group will be displayed, or none of it will. This obivously has
             culling issues.
-        @li A single world transform must apply to the entire batch. Therefore
+        - A single world transform must apply to the entire batch. Therefore
             once you have batched things, you can't move them around relative to
             each other. That's why this class is most useful when dealing with 
             static geometry (hence the name). In addition, geometry is 
@@ -68,18 +59,18 @@ namespace Ogre {
             space than the movable version (which re-uses the same geometry). 
             So you trade memory and flexibility of movement for pure speed when
             using this class.
-        @li A single material must apply for each batch. In fact this class 
+        - A single material must apply for each batch. In fact this class
             allows you to use multiple materials, but you should be aware that 
             internally this means that there is one batch per material. 
             Therefore you won't gain as much benefit from the batching if you 
             use many different materials; try to keep the number down.
-    @par
+
         In order to retain some sort of culling, this class will batch up 
         meshes in localised regions. The size and shape of these blocks is
         controlled by the SceneManager which constructs this object, since it
         makes sense to batch things up in the most appropriate way given the 
         existing partitioning of the scene. 
-    @par
+
         The LOD settings of both the Mesh and the Materials used in 
         constructing this static geometry will be respected. This means that 
         if you use meshes/materials which have LOD, batches in the distance 
@@ -91,15 +82,15 @@ namespace Ogre {
         not degraded). Be aware that using Mesh LOD in this class will 
         further increase the memory required. Only generated LOD
         is supported for meshes.
-    @par
+
         There are 2 ways you can add geometry to this class; you can add
         Entity objects directly with predetermined positions, scales and 
         orientations, or you can add an entire SceneNode and it's subtree, 
         including all the objects attached to it. Once you've added everything
         you need to, you have to call build() the fix the geometry in place. 
     @note
-        This class is not a replacement for world geometry (@see 
-        SceneManager::setWorldGeometry). The single most efficient way to 
+        This class is not a replacement for world geometry (@ref
+        Ogre::SceneManager::setWorldGeometry). The single most efficient way to
         render large amounts of static geometry is to use a SceneManager which 
         is specialised for dealing with that particular world structure. 
         However, this class does provide you with a good 'halfway house'
@@ -107,14 +98,8 @@ namespace Ogre {
         SceneManagers but isn't efficient when using very large numbers, and 
         highly specialised world geometry which is extremely fast but not 
         generic and typically requires custom world editors.
-    @par
-        You should not construct instances of this class directly; instead, cal 
-        SceneManager::createStaticGeometry, which gives the SceneManager the 
-        option of providing you with a specialised version of this class if it
-        wishes, and also handles the memory management for you like other 
-        classes.
-    @note
-        Warning: this class only works with indexed triangle lists at the moment,
+    @attention
+        this class only works with indexed triangle lists at the moment,
         do not pass it triangle strips, fans or lines / points, or unindexed geometry.
     */
     class _OgreExport StaticGeometry : public BatchedGeometryAlloc
@@ -210,13 +195,13 @@ namespace Ogre {
             /// Get the index data for this geometry 
             const IndexData* getIndexData(void) const { return mIndexData; }
             /// @copydoc Renderable::getMaterial
-            const MaterialPtr& getMaterial(void) const;
-            Technique* getTechnique(void) const;
-            void getRenderOperation(RenderOperation& op);
-            void getWorldTransforms(Matrix4* xform) const;
-            Real getSquaredViewDepth(const Camera* cam) const;
-            const LightList& getLights(void) const;
-            bool getCastsShadows(void) const;
+            const MaterialPtr& getMaterial(void) const override;
+            Technique* getTechnique(void) const override;
+            void getRenderOperation(RenderOperation& op) override;
+            void getWorldTransforms(Matrix4* xform) const override;
+            Real getSquaredViewDepth(const Camera* cam) const override;
+            const LightList& getLights(void) const override;
+            bool getCastsShadows(void) const override;
             
             /** Try to assign geometry to this bucket.
             @return false if there is no room left in this bucket
@@ -225,7 +210,7 @@ namespace Ogre {
             /// Build
             void build(bool stencilShadows);
             /// Dump contents for diagnostics
-            void dump(std::ofstream& of) const;
+            _OgreExport friend std::ostream& operator<<(std::ostream& o, const GeometryBucket& b);
         };
         /** A MaterialBucket is a collection of smaller buckets with the same 
             Material (and implicitly the same LOD). */
@@ -274,7 +259,7 @@ namespace Ogre {
             /// Get the current Technique
             Technique* getCurrentTechnique(void) const { return mTechnique; }
             /// Dump contents for diagnostics
-            void dump(std::ofstream& of) const;
+            _OgreExport friend std::ostream& operator<<(std::ostream& o, const MaterialBucket& b);
             void visitRenderables(Renderable::Visitor* visitor, bool debugRenderables);
         };
         /** A LODBucket is a collection of smaller buckets with the same LOD. 
@@ -326,7 +311,7 @@ namespace Ogre {
             /// @deprecated use getMaterialBuckets()
             OGRE_DEPRECATED MaterialIterator getMaterialIterator(void);
             /// Dump contents for diagnostics
-            void dump(std::ofstream& of) const;
+            _OgreExport friend std::ostream& operator<<(std::ostream& o, const LODBucket& b);
             void visitRenderables(Renderable::Visitor* visitor, bool debugRenderables);
             EdgeData* getEdgeList() const { return mEdgeList; }
             ShadowCaster::ShadowRenderableList& getShadowRenderableList() { return mShadowRenderables; }
@@ -393,16 +378,16 @@ namespace Ogre {
             uint32 getID(void) const { return mRegionID; }
             /// Get the centre point of the region
             const Vector3& getCentre(void) const { return mCentre; }
-            const String& getMovableType(void) const;
-            void _notifyCurrentCamera(Camera* cam);
-            const AxisAlignedBox& getBoundingBox(void) const;
-            Real getBoundingRadius(void) const;
-            void _updateRenderQueue(RenderQueue* queue);
+            const String& getMovableType(void) const override;
+            void _notifyCurrentCamera(Camera* cam) override;
+            const AxisAlignedBox& getBoundingBox(void) const override;
+            Real getBoundingRadius(void) const override;
+            void _updateRenderQueue(RenderQueue* queue) override;
             /// @copydoc MovableObject::visitRenderables
             void visitRenderables(Renderable::Visitor* visitor, 
-                bool debugRenderables = false);
-            bool isVisible(void) const;
-            uint32 getTypeFlags(void) const;
+                bool debugRenderables = false) override;
+            bool isVisible(void) const override;
+            uint32 getTypeFlags(void) const override;
 
             typedef VectorIterator<LODBucketList> LODIterator;
             /// @deprecated use getLODBuckets()
@@ -419,7 +404,7 @@ namespace Ogre {
             void _restoreManualHardwareResources() override;
 
             /// Dump contents for diagnostics
-            void dump(std::ofstream& of) const;
+            _OgreExport friend std::ostream& operator<<(std::ostream& o, const Region& r);
             
         };
         /** Indexed region map based on packed x/y/z region index, 10 bits for
@@ -532,7 +517,12 @@ namespace Ogre {
         }
         
     public:
-        /// Constructor; do not use directly (@see SceneManager::createStaticGeometry)
+        /**
+            You should not construct instances of this class directly; instead, call
+            SceneManager::createStaticGeometry, which gives the SceneManager the
+            option of providing you with a specialised version of this class if it
+            wishes, and also handles the memory management for you like other classes.
+         */
         StaticGeometry(SceneManager* owner, const String& name);
         /// Destructor
         virtual ~StaticGeometry();
@@ -556,6 +546,8 @@ namespace Ogre {
         @param position The world position at which to add this Entity
         @param orientation The world orientation at which to add this Entity
         @param scale The scale at which to add this entity
+        @attention Do not unload the Mesh used by the Entity until after you have
+            called build(), as the geometry is read at that time.
         */
         virtual void addEntity(Entity* ent, const Vector3& position,
             const Quaternion& orientation = Quaternion::IDENTITY, 
@@ -576,6 +568,8 @@ namespace Ogre {
             versions! We don't do this for you in case you are preparing this
             in advance and so don't want the originals detached yet. 
         @note Must be called before 'build'.
+        @attention Do not unload the Mesh used by the Entities until after you have
+            called build(), as the geometry is read at that time.
         @param node Pointer to the node to use to provide a set of Entity 
             templates
         */
@@ -598,12 +592,12 @@ namespace Ogre {
             You can call build() again after this and it will pick up all the
             same entities / nodes you queued last time.
         */
-        virtual void destroy(void);
+        void destroy(void);
 
         /** Clears any of the entities / nodes added to this geometry and 
             destroys anything which has already been built.
         */
-        virtual void reset(void);
+        void reset(void);
 
         /** Sets the distance at which batches are no longer rendered.
 
@@ -715,25 +709,10 @@ namespace Ogre {
         /// @deprecated use getRegions()
         OGRE_DEPRECATED RegionIterator getRegionIterator(void);
 
-        /** Dump the contents of this StaticGeometry to a file for diagnostic
+        /** Dump the contents of this StaticGeometry for diagnostic
             purposes.
         */
-        virtual void dump(const String& filename) const;
-
-
-    };
-
-    /** Dummy factory to let Regions adhere to MovableObject protocol */
-    class _OgreExport StaticGeometryFactory : public MovableObjectFactory
-    {
-        MovableObject* createInstanceImpl( const String& name, const NameValuePairList* params) { return NULL; }
-    public:
-        StaticGeometryFactory() {}
-        ~StaticGeometryFactory() {}
-
-        static String FACTORY_TYPE_NAME;
-
-        const String& getType(void) const { return FACTORY_TYPE_NAME; }
+        _OgreExport friend std::ostream& operator<<(std::ostream& o, const StaticGeometry& g);
     };
     /** @} */
     /** @} */
