@@ -125,7 +125,7 @@ namespace Ogre {
 
         RenderSystemCapabilities* createRenderSystemCapabilities() const override;
 
-        void initialiseFromRenderSystemCapabilities(RenderSystemCapabilities* caps, RenderTarget* primary) override;
+        void initialiseFromRenderSystemCapabilities(RenderSystemCapabilities* caps, RenderTarget* = NULL) override;
 
         void shutdown(void) override;
 
@@ -139,9 +139,6 @@ namespace Ogre {
         /// @copydoc RenderSystem::createMultiRenderTarget
         MultiRenderTarget * createMultiRenderTarget(const String & name) override;
 
-
-        void destroyRenderWindow(const String& name) override;
-
         // -----------------------------
         // Low-level overridden members
         // -----------------------------
@@ -216,6 +213,8 @@ namespace Ogre {
          */
         void _setRenderTarget(RenderTarget *target) override;
 
+        void bindRenderTarget(RenderTarget* target) override;
+
         static GLint convertCompareFunction(CompareFunction func);
         static GLint convertStencilOp(StencilOperation op, bool invert = false);
 
