@@ -1,5 +1,5 @@
 var _ogre_resource_8h =
 [
     [ "Ogre::Resource::Listener", "class_ogre_1_1_resource_1_1_listener.html", "class_ogre_1_1_resource_1_1_listener" ],
-    [ "ResourceHandle", "_ogre_resource_8h.html#a4028e4b3764034d4b2ff51359550a9fb", null ]
+    [ "Ogre::ResourceHandle", "namespace_ogre.html#a4028e4b3764034d4b2ff51359550a9fb", null ]
 ];
\ No newline at end of file
