@@ -15,5 +15,6 @@ var class_ogre_1_1_compositor_instance_1_1_target_operation =
     [ "materialScheme", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#ac5258ce0ba7b24c2854ec37543daa59f", null ],
     [ "shadowsEnabled", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#ac130ef8cace8c4af74ba60f37deb25fe", null ],
     [ "cameraOverride", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a34bc78096837ffec607502b4d9b04da6", null ],
-    [ "alignCameraToFace", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a9f0ff12a7501fa0668d6ede6e18a913f", null ]
+    [ "alignCameraToFace", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a9f0ff12a7501fa0668d6ede6e18a913f", null ],
+    [ "swapBuffers", "class_ogre_1_1_compositor_instance_1_1_target_operation.html#a7e995420722b1cb490a87876cddf5d99", null ]
 ];
\ No newline at end of file
