@@ -145,8 +145,8 @@ var class_ogre_1_1_terrain =
     [ "getCompositeMapMaterial", "class_ogre_1_1_terrain.html#abde5a9931a278de23697fe6996a0e6d9", null ],
     [ "_getCompositeMapMaterial", "class_ogre_1_1_terrain.html#a53a08891b2dec0febd07bde5680598e7", null ],
     [ "getMaterialName", "class_ogre_1_1_terrain.html#adc32dec06092d0cdf5c89830aa217d41", null ],
-    [ "preFindVisibleObjects", "class_ogre_1_1_terrain.html#ad9bd9a0fbdb32cb5571cca586f21e811", null ],
-    [ "sceneManagerDestroyed", "class_ogre_1_1_terrain.html#a09baa91af04f211ee9e8e8f60d9e6c39", null ],
+    [ "preFindVisibleObjects", "class_ogre_1_1_terrain.html#ac1f87183250b885c01270a68d80236e4", null ],
+    [ "sceneManagerDestroyed", "class_ogre_1_1_terrain.html#a5f7edff06d941d5621aad56c7d19c939", null ],
     [ "getRenderQueueGroup", "class_ogre_1_1_terrain.html#a85c8ed1f55d5cf5300e2ccc2d02ab2f5", null ],
     [ "setRenderQueueGroup", "class_ogre_1_1_terrain.html#a9ff521bcc0fb0193d9105af627af5c0d", null ],
     [ "getVisibilityFlags", "class_ogre_1_1_terrain.html#a124354ea9deb52eced5e1d5a75a2b996", null ],
@@ -176,11 +176,6 @@ var class_ogre_1_1_terrain =
     [ "_setLightMapRequired", "class_ogre_1_1_terrain.html#a915121f91285f370bd1a01842991ae03", null ],
     [ "_setCompositeMapRequired", "class_ogre_1_1_terrain.html#a10b9f303b81585c1b51d0c273f03a5dd", null ],
     [ "_getUseVertexCompression", "class_ogre_1_1_terrain.html#a3b379afd3348efd5c8e5a87f0b2d0729", null ],
-    [ "canHandleRequest", "class_ogre_1_1_terrain.html#a22196f59f8f761e7fc4bea11db488252", null ],
-    [ "handleRequest", "class_ogre_1_1_terrain.html#a09fa76cb7d0c852aa15b5beb7a0433ea", null ],
-    [ "canHandleResponse", "class_ogre_1_1_terrain.html#a3e3d8150704d279630a3a125b0439138", null ],
-    [ "handleResponse", "class_ogre_1_1_terrain.html#ad963dbee0f58e887e05c982385fb9799", null ],
-    [ "handleGenerateMaterialResponse", "class_ogre_1_1_terrain.html#a584b511e44e1c33c387987187446353a", null ],
     [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#aca2087cd57d5c80ccf2e983acddb1887", null ],
     [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#a2f98ad8c78b6046d4d4f4dcf9d367fae", null ],
     [ "getQuadTree", "class_ogre_1_1_terrain.html#a69e78ec7eab8aece2d20df966f0dce49", null ],
@@ -211,7 +206,6 @@ var class_ogre_1_1_terrain =
     [ "TERRAIN_CHUNK_ID", "class_ogre_1_1_terrain.html#ad1b6d65618e1ebc55155214f3b10b337", null ],
     [ "TERRAIN_CHUNK_VERSION", "class_ogre_1_1_terrain.html#afd3641ddf000f3e2ca771408f558131b", null ],
     [ "TERRAIN_MAX_BATCH_SIZE", "class_ogre_1_1_terrain.html#a5c204799a40adae8b01411ec05dbc841", null ],
-    [ "TERRAIN_GENERATE_MATERIAL_INTERVAL_MS", "class_ogre_1_1_terrain.html#a1333f67a868e2e38123ab5c4532cc8e1", null ],
     [ "TERRAINLAYERDECLARATION_CHUNK_ID", "class_ogre_1_1_terrain.html#ac83d9fa6c4ba65db9c7ad66bbd01b0de", null ],
     [ "TERRAINLAYERDECLARATION_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a14ce718231ed706aec11489fc6843d76", null ],
     [ "TERRAINLAYERSAMPLER_CHUNK_ID", "class_ogre_1_1_terrain.html#a53d1561777a42b20c5aa5a42dd96bf9b", null ],
@@ -228,7 +222,5 @@ var class_ogre_1_1_terrain =
     [ "DERIVED_DATA_DELTAS", "class_ogre_1_1_terrain.html#adc4deb8ce09c46f3d6215ea1ff390959", null ],
     [ "DERIVED_DATA_NORMALS", "class_ogre_1_1_terrain.html#a633492f40707af756814bca31f0f35ba", null ],
     [ "DERIVED_DATA_LIGHTMAP", "class_ogre_1_1_terrain.html#a1ebde7f1f98abe26938397f7110c88f3", null ],
-    [ "DERIVED_DATA_ALL", "class_ogre_1_1_terrain.html#aaef9ac3a5d1ceed0260a17f93b88d848", null ],
-    [ "WORKQUEUE_DERIVED_DATA_REQUEST", "class_ogre_1_1_terrain.html#a0441ddb006dede009b3725e0a5536bba", null ],
-    [ "WORKQUEUE_GENERATE_MATERIAL_REQUEST", "class_ogre_1_1_terrain.html#aaa21ee42164657f45f932c5f70c590a0", null ]
+    [ "DERIVED_DATA_ALL", "class_ogre_1_1_terrain.html#aaef9ac3a5d1ceed0260a17f93b88d848", null ]
 ];
\ No newline at end of file
