@@ -3,9 +3,7 @@ var dir_7bef01559623467e3671f0ffd7f0840e =
     [ "OgreOctree.h", "_ogre_octree_8h.html", null ],
     [ "OgreOctreeCamera.h", "_ogre_octree_camera_8h.html", null ],
     [ "OgreOctreeNode.h", "_ogre_octree_node_8h.html", null ],
-    [ "OgreOctreePlugin.h", "_ogre_octree_plugin_8h.html", [
-      [ "Ogre::OctreePlugin", "class_ogre_1_1_octree_plugin.html", "class_ogre_1_1_octree_plugin" ]
-    ] ],
+    [ "OgreOctreePlugin.h", "_ogre_octree_plugin_8h.html", "_ogre_octree_plugin_8h" ],
     [ "OgreOctreeSceneManager.h", "_ogre_octree_scene_manager_8h.html", "_ogre_octree_scene_manager_8h" ],
     [ "OgreOctreeSceneQuery.h", "_ogre_octree_scene_query_8h.html", null ]
 ];
\ No newline at end of file
