@@ -235,7 +235,7 @@ var group___animation =
       [ "_getBindingPoseInverseOrientation", "class_ogre_1_1_bone.html#a728ef3b318e7133ed8a7bef3839df02b", null ],
       [ "needUpdate", "class_ogre_1_1_bone.html#a99ebcfdf0a1516782b949dc0feb4c53c", null ]
     ] ],
-    [ "Ogre::Controller< T >", "class_ogre_1_1_controller.html", [
+    [ "Ogre::Controller&lt; T &gt;", "class_ogre_1_1_controller.html", [
       [ "Controller", "class_ogre_1_1_controller.html#a3fb917fd69fdc9d6799913970039652b", null ],
       [ "~Controller", "class_ogre_1_1_controller.html#ab0ba3276e026fdd9d6779e043a250617", null ],
       [ "setSource", "class_ogre_1_1_controller.html#a5432e56160bfd643bdcc0348ad191e11", null ],
@@ -248,7 +248,7 @@ var group___animation =
       [ "getFunction", "class_ogre_1_1_controller.html#acec72e8c416a5809af4a430089277a03", null ],
       [ "update", "class_ogre_1_1_controller.html#a4b16ce7b5a436c3f895bea7960bdcb07", null ]
     ] ],
-    [ "Ogre::ControllerFunction< T >", "class_ogre_1_1_controller_function.html", [
+    [ "Ogre::ControllerFunction&lt; T &gt;", "class_ogre_1_1_controller_function.html", [
       [ "ControllerFunction", "class_ogre_1_1_controller_function.html#ae7f7207fb3ce7e252fef5941da9ebc24", null ],
       [ "~ControllerFunction", "class_ogre_1_1_controller_function.html#a00ae7d50d2009c39e90a623e47a451c3", null ],
       [ "calculate", "class_ogre_1_1_controller_function.html#a0f77d037a78ce3b430c0a18fbe711df0", null ]
@@ -279,7 +279,7 @@ var group___animation =
       [ "getSingleton", "class_ogre_1_1_controller_manager.html#aab98c716e9ec8cb02d50c6c4871f91a0", null ],
       [ "getSingletonPtr", "class_ogre_1_1_controller_manager.html#ae1ebca338d463834b88b523fed7903ed", null ]
     ] ],
-    [ "Ogre::ControllerValue< T >", "class_ogre_1_1_controller_value.html", [
+    [ "Ogre::ControllerValue&lt; T &gt;", "class_ogre_1_1_controller_value.html", [
       [ "~ControllerValue", "class_ogre_1_1_controller_value.html#a3f27d2383b9e994be2ee5cb71fc603fd", null ],
       [ "getValue", "class_ogre_1_1_controller_value.html#a745741bba579264e57d797683d3feacd", null ],
       [ "setValue", "class_ogre_1_1_controller_value.html#ab719e69a47857662b71041b9c74e546b", null ]
@@ -405,16 +405,16 @@ var group___animation =
       [ "createBone", "class_ogre_1_1_skeleton.html#af70733b22fe8ba375da1657322faa1be", null ],
       [ "createBone", "class_ogre_1_1_skeleton.html#a62fafd7d136d0abfb5e857e3d81a9db5", null ],
       [ "createBone", "class_ogre_1_1_skeleton.html#a0b6960f9d334d7c9f7cff76ec0a462fb", null ],
-      [ "getNumBones", "class_ogre_1_1_skeleton.html#af0c6403322d6f5860ec8a74697575f50", null ],
+      [ "getNumBones", "class_ogre_1_1_skeleton.html#a4daefd706302f4b30487a21dc41a7591", null ],
       [ "getRootBoneIterator", "class_ogre_1_1_skeleton.html#ab385926120199e5a6535729f931c6367", null ],
       [ "getRootBones", "class_ogre_1_1_skeleton.html#ad44d80310bb92c67c339c9b2fb2c51cd", null ],
       [ "getBoneIterator", "class_ogre_1_1_skeleton.html#a397bf260ff70afd076cd7be9d163fc35", null ],
       [ "getBones", "class_ogre_1_1_skeleton.html#a18ba16f4455a6dde3f5ffb6ef05c6ed6", null ],
-      [ "getBone", "class_ogre_1_1_skeleton.html#ac1b8d22602ba9961bda950aaa7e677c7", null ],
-      [ "getBone", "class_ogre_1_1_skeleton.html#adec24b393315df9ace870d70668aa63e", null ],
-      [ "hasBone", "class_ogre_1_1_skeleton.html#a2c9370f5a79002c9ebb7d66a5a0b39ef", null ],
-      [ "setBindingPose", "class_ogre_1_1_skeleton.html#ae1f1e2f2cb6ac088684d814023abcc36", null ],
-      [ "reset", "class_ogre_1_1_skeleton.html#a8e0d4478cbb8f44f638ae8d1d72ff3fb", null ],
+      [ "getBone", "class_ogre_1_1_skeleton.html#ad5a54df96260490b26733605eddeefa5", null ],
+      [ "getBone", "class_ogre_1_1_skeleton.html#a5c2707d431c5b7e78df78b7576d02eaa", null ],
+      [ "hasBone", "class_ogre_1_1_skeleton.html#a111d077fda4ee4f3ae1f287f2386b4c2", null ],
+      [ "setBindingPose", "class_ogre_1_1_skeleton.html#a2b530e5695af45a72c218ae16b7591c7", null ],
+      [ "reset", "class_ogre_1_1_skeleton.html#a8fd602fa19928a30d4a25ce764037e63", null ],
       [ "createAnimation", "class_ogre_1_1_skeleton.html#a97fe99825462df6b8300191345e880cb", null ],
       [ "getAnimation", "class_ogre_1_1_skeleton.html#a615318f8970acd8b7d3334944b77a771", null ],
       [ "getAnimation", "class_ogre_1_1_skeleton.html#a039a9be4ad73b3e03550dc2269ddda1f", null ],
@@ -424,11 +424,11 @@ var group___animation =
       [ "setAnimationState", "class_ogre_1_1_skeleton.html#a3f7632e047bb6e65fff3c536612fedb7", null ],
       [ "_initAnimationState", "class_ogre_1_1_skeleton.html#af124af663b4df4118eea93c3a326cf69", null ],
       [ "_refreshAnimationState", "class_ogre_1_1_skeleton.html#aa665d3816bed0f4fe5615ddd36c5496a", null ],
-      [ "_getBoneMatrices", "class_ogre_1_1_skeleton.html#abc7949e274554535b9f40b70b87f646a", null ],
+      [ "_getBoneMatrices", "class_ogre_1_1_skeleton.html#a91be372a024cc9502e5df22f63626c87", null ],
       [ "getNumAnimations", "class_ogre_1_1_skeleton.html#a0f0268b2017152a7ba989ee3a72b6dda", null ],
       [ "getAnimation", "class_ogre_1_1_skeleton.html#a6954a703d5576e85a22fdba7498aa830", null ],
-      [ "getBlendMode", "class_ogre_1_1_skeleton.html#a1a3a60c6a44517d3dc5c23c7fcb109bd", null ],
-      [ "setBlendMode", "class_ogre_1_1_skeleton.html#a0afe24842c40767f308ee7c2f04e999e", null ],
+      [ "getBlendMode", "class_ogre_1_1_skeleton.html#aa4a92e098811b5f16afaf955beb4a8f1", null ],
+      [ "setBlendMode", "class_ogre_1_1_skeleton.html#ad35d4f821bcf19df3468be507f069da3", null ],
       [ "_updateTransforms", "class_ogre_1_1_skeleton.html#a5d4648d138e39e3ca34f76558bfedf55", null ],
       [ "optimiseAllAnimations", "class_ogre_1_1_skeleton.html#a542c24dc374d0ff8ba4ecdda99b5da06", null ],
       [ "addLinkedSkeletonAnimationSource", "class_ogre_1_1_skeleton.html#a162794b4b599410e395ad9ed0a7eac64", null ],
