@@ -65,11 +65,8 @@ var group___bites =
       [ "removeInputListener", "class_ogre_bites_1_1_application_context_qt.html#a373bb09eb2c04dd01041b3572c2e7ee3", null ],
       [ "pollEvents", "class_ogre_bites_1_1_application_context_qt.html#ad88ac20d3f886bf9d99c08a3df372f51", null ],
       [ "shutdown", "class_ogre_bites_1_1_application_context_qt.html#aaa7a24812db6e040aab41b663407bca5", null ],
-      [ "setWindowGrab", "class_ogre_bites_1_1_application_context_qt.html#a3468e25346921b9d9dc277ffe8d530aa", null ],
       [ "setWindowGrab", "class_ogre_bites_1_1_application_context_qt.html#a5149884c61334711e13008767885af65", null ],
-      [ "addInputListener", "class_ogre_bites_1_1_application_context_qt.html#ad08c5d9724cea17a9e59a5d4f4e6c434", null ],
       [ "addInputListener", "class_ogre_bites_1_1_application_context_qt.html#a759499ca97dde7ab476b99165f858831", null ],
-      [ "removeInputListener", "class_ogre_bites_1_1_application_context_qt.html#a2e097414054773d2cc1812268011c440", null ],
       [ "removeInputListener", "class_ogre_bites_1_1_application_context_qt.html#ae0c27985a012d1d0d9e4ee6f7b0659a2", null ]
     ] ],
     [ "OgreBites::CameraMan", "class_ogre_bites_1_1_camera_man.html", [
