@@ -19,7 +19,7 @@ var group___image =
       [ "loadRawData", "class_ogre_1_1_image.html#a19cbedd586cda280a36de5aaae6874e7", null ],
       [ "loadRawData", "class_ogre_1_1_image.html#a30aab2634e40b600171794123e98f63b", null ],
       [ "load", "class_ogre_1_1_image.html#a5312a67dfaeb1716ae9ab72c1af766cb", null ],
-      [ "load", "class_ogre_1_1_image.html#ad232b6f23c99d07e1b801579f97c9997", null ],
+      [ "load", "class_ogre_1_1_image.html#a57f15052fc60ab5f098680d7d6ab99ff", null ],
       [ "loadTwoImagesAsRGBA", "class_ogre_1_1_image.html#a9637f7e84d6869469842dd693fa0a23b", null ],
       [ "loadTwoImagesAsRGBA", "class_ogre_1_1_image.html#a4bba1b24287b72855b2ddfc67b3f0b6a", null ],
       [ "combineTwoImagesAsRGBA", "class_ogre_1_1_image.html#a59c76c792fda5b2c8c6d064451eb3121", null ],
@@ -51,30 +51,7 @@ var group___image =
       [ "getFileExtFromMagic", "class_ogre_1_1_image.html#abfa974d7e6060aa68bf6105156be7069", null ],
       [ "ImageCodec", "class_ogre_1_1_image.html#a6147b4b5d8c1dcb429c210e57b31496b", null ]
     ] ],
-    [ "Ogre::ImageCodec", "class_ogre_1_1_image_codec.html", [
-      [ "ImageData", "class_ogre_1_1_image_codec_1_1_image_data.html", [
-        [ "ImageData", "class_ogre_1_1_image_codec_1_1_image_data.html#ae79def312c157ada9d4aedcd38c911bf", null ],
-        [ "height", "class_ogre_1_1_image_codec_1_1_image_data.html#ac8e81c2ca0110cf97d15d60f9f1372ce", null ],
-        [ "width", "class_ogre_1_1_image_codec_1_1_image_data.html#a36b700d1bf8f15c1876d2d1f4ceb0c93", null ],
-        [ "depth", "class_ogre_1_1_image_codec_1_1_image_data.html#a72aae51984f895eb73161a24b1d739a5", null ],
-        [ "size", "class_ogre_1_1_image_codec_1_1_image_data.html#adf09c2a3243681cfb4f38f8c6074d111", null ],
-        [ "num_mipmaps", "class_ogre_1_1_image_codec_1_1_image_data.html#a9cf2bfbd7b0ee7ffe15b37dd148410f8", null ],
-        [ "flags", "class_ogre_1_1_image_codec_1_1_image_data.html#a17daec36bcb3a0a3084576fe4f913551", null ],
-        [ "format", "class_ogre_1_1_image_codec_1_1_image_data.html#af59eaab36e6dc3c20124af20655f6338", null ]
-      ] ],
-      [ "CodecDataPtr", "class_ogre_1_1_image_codec.html#a2084767efd9180be39a01fd1117cdbcc", null ],
-      [ "DecodeResult", "class_ogre_1_1_image_codec.html#a5de6ad1dfcdb1da1bdc36f4118b0fae7", null ],
-      [ "~ImageCodec", "class_ogre_1_1_image_codec.html#abc965356799dafed861787b57e7631e6", null ],
-      [ "decode", "class_ogre_1_1_image_codec.html#af7ad1af418b249cc41c7dbac88b4ed60", null ],
-      [ "encode", "class_ogre_1_1_image_codec.html#a143d3a5d6bd38456a77429e39c3653cc", null ],
-      [ "encodeToFile", "class_ogre_1_1_image_codec.html#a823ed602f4fd80a51610f7714b713d20", null ],
-      [ "encode", "class_ogre_1_1_image_codec.html#a3ee3164993b22fdd2357e90da74f0740", null ],
-      [ "encodeToFile", "class_ogre_1_1_image_codec.html#a27f865b183e77e14e00662c904f37eee", null ],
-      [ "decode", "class_ogre_1_1_image_codec.html#a3d820588d7a6469d4ce94917d33b158e", null ],
-      [ "decode", "class_ogre_1_1_image_codec.html#a90fbb1197d6d09cd8a9ca865e891cc4d", null ],
-      [ "encode", "class_ogre_1_1_image_codec.html#a8356df26fc21ff98ce8c1c66a2a2d784", null ],
-      [ "encodeToFile", "class_ogre_1_1_image_codec.html#a5e7ecc1371add6ffa98d807dda1c8da3", null ]
-    ] ],
+    [ "Ogre::ImageCodec", "class_ogre_1_1_image_codec.html", null ],
     [ "Ogre::PixelBox", "class_ogre_1_1_pixel_box.html", [
       [ "PixelBox", "class_ogre_1_1_pixel_box.html#a196c57b3cf61c1545c46896cff269efb", null ],
       [ "~PixelBox", "class_ogre_1_1_pixel_box.html#a5a5191d05b7ec15bb97c98807c271f35", null ],
@@ -95,8 +72,8 @@ var group___image =
       [ "format", "class_ogre_1_1_pixel_box.html#aa4101fdc288dc41dddac88440b4d0818", null ]
     ] ],
     [ "Ogre::PixelUtil", "class_ogre_1_1_pixel_util.html", [
-      [ "getNumElemBytes", "class_ogre_1_1_pixel_util.html#a1e39ec27d40f044a058e6fef850a1fbe", null ],
-      [ "getNumElemBits", "class_ogre_1_1_pixel_util.html#a1dbc281fe64d9f70b3ce5e6d3011cafb", null ],
+      [ "getNumElemBytes", "class_ogre_1_1_pixel_util.html#a4c2d79d422b66107a8110d65dbf27614", null ],
+      [ "getNumElemBits", "class_ogre_1_1_pixel_util.html#a7c287569565b348b6e58f2e7c9753f6a", null ],
       [ "getMemorySize", "class_ogre_1_1_pixel_util.html#a865aa435b593756fe2d2bd2463a18199", null ],
       [ "getFlags", "class_ogre_1_1_pixel_util.html#ae0c13cd6390b11bc851c9e2ba1201f40", null ],
       [ "hasAlpha", "class_ogre_1_1_pixel_util.html#a1e15a9f2c0dc1cba158755633574fbc7", null ],
@@ -112,7 +89,7 @@ var group___image =
       [ "getFormatName", "class_ogre_1_1_pixel_util.html#a75b2a9433791b9e647b11587d4d24fb8", null ],
       [ "isAccessible", "class_ogre_1_1_pixel_util.html#a2a9e6ac27e4a4cb2d890d322b3f12c8e", null ],
       [ "getComponentType", "class_ogre_1_1_pixel_util.html#a90ebf73b3830df2e83d529e60fd8c385", null ],
-      [ "getComponentCount", "class_ogre_1_1_pixel_util.html#ae81ba2514ca7f5a53c84bb515de2ade0", null ],
+      [ "getComponentCount", "class_ogre_1_1_pixel_util.html#a693c6857d06d175a9c150ce83e682967", null ],
       [ "getFormatFromName", "class_ogre_1_1_pixel_util.html#a601fd16392331e7ddce6bcc455b5729d", null ],
       [ "getFormatForBitDepths", "class_ogre_1_1_pixel_util.html#ae127c3e6145af784e7d2d3734681a75a", null ],
       [ "packColour", "class_ogre_1_1_pixel_util.html#a793a7ae2bb8edec89ab520958ac33f40", null ],
