@@ -666,7 +666,7 @@ var group___math =
       [ "build", "class_ogre_1_1_tangent_space_calc.html#a6a40ae15c9fd4912a8bd63b91997bbe8", null ],
       [ "build", "class_ogre_1_1_tangent_space_calc.html#aef80f3ebc3e34e9fc0cca9a7ebb25d8b", null ]
     ] ],
-    [ "Ogre::TransformBase< rows, T >", "class_ogre_1_1_transform_base.html", [
+    [ "Ogre::TransformBase&lt; rows, T &gt;", "class_ogre_1_1_transform_base.html", [
       [ "TransformBase", "class_ogre_1_1_transform_base.html#acf3bcb9d0a7bffe8a2de6bb629db7c22", null ],
       [ "TransformBase", "class_ogre_1_1_transform_base.html#a8ad24267976ae7b6f588bf3164aaf46a", null ],
       [ "TransformBase", "class_ogre_1_1_transform_base.html#a7a196d18c3ea563e3c7d6f98867e3148", null ],
@@ -691,7 +691,7 @@ var group___math =
       [ "makeTransform", "struct_ogre_1_1_transform_base_real.html#ad58c2d3fb3345558228fe3bafdf1b732", null ],
       [ "makeInverseTransform", "struct_ogre_1_1_transform_base_real.html#abf2a16142c5dfd6360fb5e697fbf578d", null ]
     ] ],
-    [ "Ogre::Vector< dims, T >", "class_ogre_1_1_vector.html", [
+    [ "Ogre::Vector&lt; dims, T &gt;", "class_ogre_1_1_vector.html", [
       [ "Vector", "class_ogre_1_1_vector.html#a7d01f88f113d198ac5ee8b961c6d8823", null ],
       [ "Vector", "class_ogre_1_1_vector.html#a5d36cecbc16d79c4014a9b3cc1596385", null ],
       [ "Vector", "class_ogre_1_1_vector.html#a823c3a88d2420a9cce22723d4271707a", null ],
@@ -746,7 +746,7 @@ var group___math =
       [ "operator/", "class_ogre_1_1_vector.html#a53dc8e9fa6980e60713fe81b09be5d54", null ],
       [ "operator<<", "class_ogre_1_1_vector.html#ac21eafda481aaffc9c767ad4f5a6dfd7", null ]
     ] ],
-    [ "Ogre::VectorBase< dims, T >", "struct_ogre_1_1_vector_base.html", [
+    [ "Ogre::VectorBase&lt; dims, T &gt;", "struct_ogre_1_1_vector_base.html", [
       [ "VectorBase", "struct_ogre_1_1_vector_base.html#a3d840979e2f40a0c01c5bac850977da0", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base.html#ad48f47252d7d3ae236a833bc7697e26d", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base.html#a770f1fd7df813537f69eca4cc61ce555", null ],
@@ -755,7 +755,7 @@ var group___math =
       [ "ptr", "struct_ogre_1_1_vector_base.html#a9caacd16230bd6ac7c00bcf40b05b055", null ],
       [ "data", "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5", null ]
     ] ],
-    [ "Ogre::VectorBase< 2, Real >", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", [
+    [ "Ogre::VectorBase&lt; 2, Real &gt;", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html", [
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#abdef156b8ae9ca99b2f6e63e545f93a3", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#aac109774d6f7e6888eb1b69df174f532", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a4386098987c58adbe2dd4fedb0d19eed", null ],
@@ -775,7 +775,7 @@ var group___math =
       [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_012_00_01_real_01_4.html#a25af7d975810f608e06393996e3fcacd", null ],
       [ "data", "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5", null ]
     ] ],
-    [ "Ogre::VectorBase< 3, Real >", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", [
+    [ "Ogre::VectorBase&lt; 3, Real &gt;", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html", [
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#afcd99d9db1e0e25bab9f7bea0d4a190a", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a51c08bbc222d2824f6702922c57df32a", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a7f6ccde75703a0965eb4bce5f99eeac2", null ],
@@ -802,7 +802,7 @@ var group___math =
       [ "UNIT_SCALE", "struct_ogre_1_1_vector_base_3_013_00_01_real_01_4.html#a859c38f8eede388a0db21746c799104c", null ],
       [ "data", "struct_ogre_1_1_vector_base.html#a1b21ec054398dd1389acf0be59e287a5", null ]
     ] ],
-    [ "Ogre::VectorBase< 4, Real >", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", [
+    [ "Ogre::VectorBase&lt; 4, Real &gt;", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html", [
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a50e16e1f758092ba72398d1f71d0bc60", null ],
       [ "VectorBase", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#af845fd6db88eccdf2a5b155f3eb26d81", null ],
       [ "ptr", "struct_ogre_1_1_vector_base_3_014_00_01_real_01_4.html#a687504a38534d7a9cf95fcc56a0ec048", null ],
