@@ -1,5 +1,6 @@
 var NAVTREEINDEX1 =
 {
+"_numpy_8py.html":[8,0,0,6,1],
 "_ogre_8h.html":[8,0,1,0,0],
 "_ogre_advanced_render_controls_8h.html":[8,0,0,0,0,0],
 "_ogre_aligned_allocator_8h.html":[8,0,1,0,1],
@@ -248,6 +249,5 @@ var NAVTREEINDEX1 =
 "_ogre_particle_system_8h.html":[8,0,1,0,116],
 "_ogre_particle_system_manager_8h.html":[8,0,1,0,117],
 "_ogre_particle_system_renderer_8h.html":[8,0,1,0,118],
-"_ogre_pass_8h.html":[8,0,1,0,119],
-"_ogre_patch_mesh_8h.html":[8,0,1,0,120]
+"_ogre_pass_8h.html":[8,0,1,0,119]
 };
