@@ -1,5 +1,18 @@
 var NAVTREEINDEX13 =
 {
+"class_ogre_1_1_distance_lod_sphere_strategy.html#a1836339ae099ab2dcebc31cfcc4a9475":[5,0,4,2,1],
+"class_ogre_1_1_distance_lod_sphere_strategy.html#a86bd0de82734a68148126e872eb92874":[5,0,4,2,2],
+"class_ogre_1_1_distance_lod_sphere_strategy.html#a99b5ef240e4230111c22e2e131474f3f":[5,0,4,2,0],
+"class_ogre_1_1_distance_lod_sphere_strategy.html#ae478d8c56d2ec46b79af762d32494127":[5,0,4,2,3],
+"class_ogre_1_1_distance_lod_strategy_base.html":[5,0,4,3],
+"class_ogre_1_1_distance_lod_strategy_base.html#a0de7722e986cdcca067bc1773feb6065":[5,0,4,3,10],
+"class_ogre_1_1_distance_lod_strategy_base.html#a15f1fe0235a041c18abd9644dbed5d87":[5,0,4,3,0],
+"class_ogre_1_1_distance_lod_strategy_base.html#a3ef487ffc2e8223fbceea0df0bb98e73":[5,0,4,3,7],
+"class_ogre_1_1_distance_lod_strategy_base.html#a4f8f711a88a7ad7308bfb58e525503ab":[5,0,4,3,8],
+"class_ogre_1_1_distance_lod_strategy_base.html#a5b60368988f8c388b97d6af77b7c08c9":[5,0,4,3,11],
+"class_ogre_1_1_distance_lod_strategy_base.html#a65d9d54235e62d66e1f25355926d7a63":[5,0,4,3,6],
+"class_ogre_1_1_distance_lod_strategy_base.html#a8a2e6192e83057b8973b5247a8ff7abe":[5,0,4,3,1],
+"class_ogre_1_1_distance_lod_strategy_base.html#ab26e68a2e700746489699bc1c70e8e18":[5,0,4,3,3],
 "class_ogre_1_1_distance_lod_strategy_base.html#acb473d444fc5b8b836b172d3baaa6a75":[5,0,4,3,4],
 "class_ogre_1_1_distance_lod_strategy_base.html#ae0eb79032a169437c7ecdad4d20e8a81":[5,0,4,3,5],
 "class_ogre_1_1_distance_lod_strategy_base.html#ae8568a566aac276fcf9f1ab7c5f19a38":[5,0,4,3,2],
@@ -236,18 +249,5 @@ var NAVTREEINDEX13 =
 "class_ogre_1_1_external_texture_source_manager.html#a79686f018264f79506bb3f3d5465584c":[5,0,5,3,7],
 "class_ogre_1_1_external_texture_source_manager.html#a7ae04c3b80a92082a11b73e35bc5ad34":[5,0,5,3,8],
 "class_ogre_1_1_external_texture_source_manager.html#a88d9b3f2fc5048d9f49465ff8a07f30f":[5,0,5,3,5],
-"class_ogre_1_1_external_texture_source_manager.html#aba3a8f5a2f49c1458f14c5f169940681":[5,0,5,3,6],
-"class_ogre_1_1_external_texture_source_manager.html#ac555acdb2331964338efe376b156ff83":[5,0,5,3,4],
-"class_ogre_1_1_external_texture_source_manager.html#afb679d92039ce0c47a43aba93cda77cd":[5,0,5,3,0],
-"class_ogre_1_1_factory_obj.html":[5,0,2,13],
-"class_ogre_1_1_factory_obj.html#a7ea883a3d14824e1b75659c7495d271a":[5,0,2,13,2],
-"class_ogre_1_1_factory_obj.html#aaebb437ff1300951ba83071c7a998725":[5,0,2,13,0],
-"class_ogre_1_1_factory_obj.html#ab14903950f7963c8c23da26ff77fedad":[5,0,2,13,3],
-"class_ogre_1_1_factory_obj.html#ae46bdfaa9ea186c7545c533572b62f8f":[5,0,2,13,1],
-"class_ogre_1_1_file_handle_data_stream.html":[5,0,8,7],
-"class_ogre_1_1_file_handle_data_stream.html#a16198eae30b14a03c4ebf1a3d2e6e762":[5,0,8,7,1],
-"class_ogre_1_1_file_handle_data_stream.html#a18495697fbafb35e7a7f0598ee2f05eb":[5,0,8,7,6],
-"class_ogre_1_1_file_handle_data_stream.html#a34724e68b6851b82f2b24258374fa36f":[5,0,8,7,7],
-"class_ogre_1_1_file_handle_data_stream.html#a8ea944090aacbf0c01b4173ffd06263d":[5,0,8,7,4],
-"class_ogre_1_1_file_handle_data_stream.html#a9b0503929f53ff42daa0eac1847a6c06":[5,0,8,7,2]
+"class_ogre_1_1_external_texture_source_manager.html#aba3a8f5a2f49c1458f14c5f169940681":[5,0,5,3,6]
 };
