@@ -1,5 +1,6 @@
 var NAVTREEINDEX2 =
 {
+"_ogre_patch_mesh_8h.html":[8,0,1,0,120],
 "_ogre_patch_surface_8h.html":[8,0,1,0,121],
 "_ogre_pixel_count_lod_strategy_8h.html":[8,0,1,0,122],
 "_ogre_pixel_format_8h.html":[8,0,1,0,123],
@@ -248,6 +249,5 @@ var NAVTREEINDEX2 =
 "_ogre_small_vector_8h.html":[8,0,0,2,0,16],
 "_ogre_sphere_8h.html":[8,0,1,0,181],
 "_ogre_static_face_group_8h.html":[8,0,2,1,0,9],
-"_ogre_static_geometry_8h.html":[8,0,1,0,182],
-"_ogre_static_plugin_loader_8h.html":[8,0,0,0,0,9]
+"_ogre_static_geometry_8h.html":[8,0,1,0,182]
 };
