@@ -1,5 +1,30 @@
 var NAVTREEINDEX61 =
 {
+"struct_ogre_1_1_lod_data.html#a9d0a2e539c50b250ae2ed5e0ca0b5037":[5,1,2,3,24],
+"struct_ogre_1_1_lod_data.html#ad376dfff6935250740314efb5e99f2dd":[5,1,2,3,9],
+"struct_ogre_1_1_lod_data.html#ad3c424670454076e0ebf1d4adc87d104":[5,1,2,3,18],
+"struct_ogre_1_1_lod_data.html#ad442682ce19f3ac65702beb032a7a6df":[5,1,2,3,13],
+"struct_ogre_1_1_lod_data.html#aed7b2a441e826b40396db08b743f9131":[5,1,2,3,15],
+"struct_ogre_1_1_lod_data.html#af59854923d539c6b74be64d67aa05de8":[5,1,2,3,23],
+"struct_ogre_1_1_lod_data.html#af69d67f001e0a9417a9507c6b6fc5581":[5,1,2,3,12],
+"struct_ogre_1_1_lod_data.html#af95ac40c4f3bdd402aa2e0cc1e25fc9c":[5,1,2,3,20],
+"struct_ogre_1_1_lod_data.html#aff7b5cabe66e52756ffc1449b72672ac":[5,1,2,3,26],
+"struct_ogre_1_1_lod_data_1_1_edge.html":[5,1,2,3,0],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a1f456b7ef93c6fdccab8c0ece50affc7":[5,1,2,3,0,3],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a3ec40b83d91916a437b48d4e8d0c4bbb":[5,1,2,3,0,6],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a6f27dffeccc65f1157b1e483bdfdfc05":[5,1,2,3,0,4],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a6fc99de5e3b82dcba93ed93ce2ec9ec3":[5,1,2,3,0,5],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a7107dc42d825d379eddfa1e972e22a0b":[5,1,2,3,0,1],
+"struct_ogre_1_1_lod_data_1_1_edge.html#a7e0e58962a7fe713743728f63a5b39db":[5,1,2,3,0,7],
+"struct_ogre_1_1_lod_data_1_1_edge.html#aef1383c820c467af702932fb8d4e08a9":[5,1,2,3,0,2],
+"struct_ogre_1_1_lod_data_1_1_edge.html#af59b284615ca330d7879fec720b15144":[5,1,2,3,0,0],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html":[5,1,2,3,1],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#a26a533a653b8980db708a5931791d961":[5,1,2,3,1,4],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#abf8765f39f6483c12cb4d25fbeefd01a":[5,1,2,3,1,0],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#acdb48ad8eaf66458a090c37b805a22be":[5,1,2,3,1,2],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#ace8f068f6f7d83cf1ae6dd0a92b26ee6":[5,1,2,3,1,1],
+"struct_ogre_1_1_lod_data_1_1_index_buffer_info.html#aef789e3ea55d0d890f1de9434d36a449":[5,1,2,3,1,3],
+"struct_ogre_1_1_lod_data_1_1_line.html":[5,1,2,3,3],
 "struct_ogre_1_1_lod_data_1_1_line.html#a6c8c2f0378dfce136a5b6e79e49f14cc":[5,1,2,3,3,5],
 "struct_ogre_1_1_lod_data_1_1_line.html#a9d5d9481ebf1384d3b1e7ee066a3768e":[5,1,2,3,3,3],
 "struct_ogre_1_1_lod_data_1_1_line.html#aa3e7051195f159e7a4ad8cfccb7e2f5b":[5,1,2,3,3,4],
@@ -224,30 +249,5 @@ var NAVTREEINDEX61 =
 "struct_ogre_1_1_static_face_group.html#a09215495af768e8a68b20cf1a937af3a":[5,0,9,53,3],
 "struct_ogre_1_1_static_face_group.html#a2dba19f0f06565cd111206a4a673239c":[5,0,9,53,6],
 "struct_ogre_1_1_static_face_group.html#a3f73219edf1201e9a3c769f9ccc672bf":[5,0,9,53,5],
-"struct_ogre_1_1_static_face_group.html#a42cad07e5dea1a57a10304dcd7b7810b":[5,0,9,53,9],
-"struct_ogre_1_1_static_face_group.html#a4b1e2bb83673099b9d2459a1bb67f429":[5,0,9,53,4],
-"struct_ogre_1_1_static_face_group.html#a5589803da362b70859d96857ba2d88c5":[5,0,9,53,7],
-"struct_ogre_1_1_static_face_group.html#a958c114788e758a02e7a0da968dc0a9b":[5,0,9,53,0],
-"struct_ogre_1_1_static_face_group.html#aa58eb0dbf0fdf7e625c80e7dbb0e76f9":[5,0,9,53,2],
-"struct_ogre_1_1_static_face_group.html#abc91f43284e36aa2376f4d54078f0480":[5,0,9,53,1],
-"struct_ogre_1_1_static_face_group.html#ad258e1806394cbd8b2efe7f39d3a7296":[5,0,9,53,8],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html":[5,0,9,54,4],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#a1a9af1b18aec22c5a9f39d487c859a0b":[5,0,9,54,4,2],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#a6ea20308c6c2919a63c24d1273f21f03":[5,0,9,54,4,1],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#ac16c7a7bff4440f883c31c85f7bf7bd2":[5,0,9,54,4,0],
-"struct_ogre_1_1_static_geometry_1_1_queued_geometry.html#af13765fe72f89bd33db5feec0beec29b":[5,0,9,54,4,3],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html":[5,0,9,54,5],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#a641f30e3a07966271a727f113a1ae529":[5,0,9,54,5,4],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#a6a73cc0fc7d1205b8bddcddf8b5a7ec8":[5,0,9,54,5,0],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#a74a6a5fd49b1797615439b118cd5395e":[5,0,9,54,5,3],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#a8bcb418431638051229f226904813245":[5,0,9,54,5,2],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#a9d003028a986c3b49cea468aa378a77b":[5,0,9,54,5,1],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#ac8f3fa1934b2e7239b4ea3fd6c0d2fb4":[5,0,9,54,5,5],
-"struct_ogre_1_1_static_geometry_1_1_queued_sub_mesh.html#acfa0525ff64b7603a33fb7c57edbee57":[5,0,9,54,5,6],
-"struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html":[5,0,9,54,7],
-"struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html#a156a3afb790d7e13663cbd7ee45faac6":[5,0,9,54,7,0],
-"struct_ogre_1_1_static_geometry_1_1_sub_mesh_lod_geometry_link.html#ac387382c92a7e1c59757e86e289e589f":[5,0,9,54,7,1],
-"struct_ogre_1_1_stencil_state.html":[5,0,7,37],
-"struct_ogre_1_1_stencil_state.html#a178cb5765005a2a6a2399f4b5a67c2da":[5,0,7,37,7],
-"struct_ogre_1_1_stencil_state.html#a17b6487c48555618f75e682471efd345":[5,0,7,37,2]
+"struct_ogre_1_1_static_face_group.html#a42cad07e5dea1a57a10304dcd7b7810b":[5,0,9,53,9]
 };
