@@ -1,5 +1,36 @@
 var NAVTREEINDEX64 =
 {
+"struct_ogre_bites_1_1_touch_finger_event.html#a56ddc53ca99755dbc2f1f24dc655cd06":[5,1,0,0,12,1],
+"struct_ogre_bites_1_1_touch_finger_event.html#aa57cc08dfd5e0ba9d8a18bb9b37b2fd2":[5,1,0,0,12,3],
+"struct_ogre_bites_1_1_touch_finger_event.html#abc13458fb67ca8baeea63c39a1138e0a":[5,1,0,0,12,5],
+"struct_ogre_bites_1_1_touch_finger_event.html#ae31fc88dca4ae639f130a9206ff64244":[5,1,0,0,12,0],
+"structbsp__brush__t.html":[7,0,3],
+"structbsp__brush__t.html#a0525b4ebc88b426a24ba4ef2a64d1f9e":[7,0,3,0],
+"structbsp__brush__t.html#aa8f2e483aa9cb18168e6d146cc7fb1b2":[7,0,3,1],
+"structbsp__brush__t.html#aca3a9ac86ba907ac43e055d4505f072b":[7,0,3,2],
+"structbsp__brushside__t.html":[7,0,4],
+"structbsp__brushside__t.html#a2538db593bd8c50a52e770fc6ac8456a":[7,0,4,1],
+"structbsp__brushside__t.html#a6091d89170ab0f354f0f573c873346d3":[7,0,4,0],
+"structbsp__face__t.html":[7,0,5],
+"structbsp__face__t.html#a13c0e8661b6ffd6f893b4c35bf7a0022":[7,0,5,5],
+"structbsp__face__t.html#a26742ad3555447b16d7d84a200df90e4":[7,0,5,7],
+"structbsp__face__t.html#a2a6371e0dfe0ca6939fd40da328bffd3":[7,0,5,2],
+"structbsp__face__t.html#a6c520802a723dcf1f887474bab5b415c":[7,0,5,6],
+"structbsp__face__t.html#a8b2ef57308bff5297ca6065a62685f59":[7,0,5,4],
+"structbsp__face__t.html#aa174fa8faa20496d0d789d8ae74dbdde":[7,0,5,13],
+"structbsp__face__t.html#aac42a7e77d3bdd9a6a9e4865201a7d1e":[7,0,5,8],
+"structbsp__face__t.html#ac295aee82ef83a80e6fb6e4123fccd32":[7,0,5,9],
+"structbsp__face__t.html#acca9215f44d568566d4176d162e58a1d":[7,0,5,0],
+"structbsp__face__t.html#ad8ed453e2e0baa9c16ffe543da198956":[7,0,5,11],
+"structbsp__face__t.html#adad5d5d0c0cf88b655bd3e5400bdfb70":[7,0,5,10],
+"structbsp__face__t.html#adf2e01928d721064f72ba3f9c2e6a2fd":[7,0,5,1],
+"structbsp__face__t.html#ae15cbcb6073a8e9d6d07262e50d59f7b":[7,0,5,3],
+"structbsp__face__t.html#ae18796a76c1cc01a88908a91ffbb18b1":[7,0,5,12],
+"structbsp__header__t.html":[7,0,6],
+"structbsp__header__t.html#a3ebea24b318355e48c5035bdca0cfd1c":[7,0,6,2],
+"structbsp__header__t.html#aa06eb21e74349ec2426f5f604caf078e":[7,0,6,0],
+"structbsp__header__t.html#ade484f9e3ff36111728c05894b5abd47":[7,0,6,1],
+"structbsp__leaf__t.html":[7,0,7],
 "structbsp__leaf__t.html#a48ac5087784ffda0c67a38cf6b29e750":[7,0,7,3],
 "structbsp__leaf__t.html#a6f98e8bd2b696a946a8c0785e3223f75":[7,0,7,0],
 "structbsp__leaf__t.html#a76b111ba9bd08e92ec345289c043248e":[7,0,7,6],
@@ -40,24 +71,24 @@ var NAVTREEINDEX64 =
 "structbsp__vis__t.html#afe3ced1a3ae54a548fd92bff20b6293b":[7,0,14,1],
 "topics.html":[5],
 "trays.html":[2,6],
-"trays.html#autotoc_md315":[2,6,1,0],
-"trays.html#autotoc_md316":[2,6,1,1],
-"trays.html#autotoc_md317":[2,6,2,0],
-"trays.html#autotoc_md318":[2,6,2,1],
-"trays.html#autotoc_md319":[2,6,2,2],
-"trays.html#autotoc_md320":[2,6,2,3],
-"trays.html#autotoc_md321":[2,6,2,4],
-"trays.html#autotoc_md322":[2,6,2,5],
-"trays.html#autotoc_md323":[2,6,2,6],
-"trays.html#autotoc_md324":[2,6,2,7],
-"trays.html#autotoc_md325":[2,6,2,8],
-"trays.html#autotoc_md326":[2,6,2,9],
-"trays.html#autotoc_md327":[2,6,2,10],
-"trays.html#autotoc_md328":[2,6,3,0],
-"trays.html#autotoc_md329":[2,6,3,1],
-"trays.html#autotoc_md330":[2,6,3,2],
-"trays.html#autotoc_md331":[2,6,3,3],
-"trays.html#autotoc_md332":[2,6,3,4],
+"trays.html#autotoc_md317":[2,6,1,0],
+"trays.html#autotoc_md318":[2,6,1,1],
+"trays.html#autotoc_md319":[2,6,2,0],
+"trays.html#autotoc_md320":[2,6,2,1],
+"trays.html#autotoc_md321":[2,6,2,2],
+"trays.html#autotoc_md322":[2,6,2,3],
+"trays.html#autotoc_md323":[2,6,2,4],
+"trays.html#autotoc_md324":[2,6,2,5],
+"trays.html#autotoc_md325":[2,6,2,6],
+"trays.html#autotoc_md326":[2,6,2,7],
+"trays.html#autotoc_md327":[2,6,2,8],
+"trays.html#autotoc_md328":[2,6,2,9],
+"trays.html#autotoc_md329":[2,6,2,10],
+"trays.html#autotoc_md330":[2,6,3,0],
+"trays.html#autotoc_md331":[2,6,3,1],
+"trays.html#autotoc_md332":[2,6,3,2],
+"trays.html#autotoc_md333":[2,6,3,3],
+"trays.html#autotoc_md334":[2,6,3,4],
 "trays.html#special-widgets":[2,6,3],
 "trays.html#things-to-try":[2,6,5],
 "trays.html#tray-listener":[2,6,4],
@@ -92,10 +123,10 @@ var NAVTREEINDEX64 =
 "tut__lights_cameras_shadows.html#bt2UsingShadowsinOgre":[2,3,4],
 "tut__lights_cameras_shadows.html#bt2Viewports":[2,3,2],
 "tut__static_geom.html":[2,10],
-"tut__static_geom.html#autotoc_md311":[2,10,0],
-"tut__static_geom.html#autotoc_md312":[2,10,1],
-"tut__static_geom.html#autotoc_md313":[2,10,2],
-"tut__static_geom.html#autotoc_md314":[2,10,3],
+"tut__static_geom.html#autotoc_md313":[2,10,0],
+"tut__static_geom.html#autotoc_md314":[2,10,1],
+"tut__static_geom.html#autotoc_md315":[2,10,2],
+"tut__static_geom.html#autotoc_md316":[2,10,3],
 "tut__terrain_sky_fog.html":[2,4],
 "tut__terrain_sky_fog.html#autotoc_md16":[2,4,0,0],
 "tut__terrain_sky_fog.html#autotoc_md17":[2,4,0,1],
@@ -121,6 +152,7 @@ var NAVTREEINDEX64 =
 "union_ogre_1_1_lod_data_1_1_index_buffer_pointer.html#ae8c433c40635ef21a8b872354f9cd454":[5,1,2,3,2,1],
 "union_ogre_bites_1_1_event.html":[5,1,0,0,2],
 "union_ogre_bites_1_1_event.html#a31b7daeb33a3e12c5e6a6a966e72c703":[5,1,0,0,2,0],
+"union_ogre_bites_1_1_event.html#a331469d3f5cbdec546304908c29e1749":[5,1,0,0,2,9],
 "union_ogre_bites_1_1_event.html#a4580f722360bd8b75b1c6ddffbcbeada":[5,1,0,0,2,7],
 "union_ogre_bites_1_1_event.html#a4b557f486480f2ff19f9966000108556":[5,1,0,0,2,1],
 "union_ogre_bites_1_1_event.html#a722998a9ff7c2401bd224f36f70da198":[5,1,0,0,2,3],
