@@ -1,5 +1,16 @@
 var NAVTREEINDEX8 =
 {
+"class_ogre_1_1_camera.html#a2876d0b5fd2f13af5a39ace745f6d039":[5,0,9,2,84],
+"class_ogre_1_1_camera.html#a2b6193430367c085dde103152a34cc5b":[5,0,9,2,14],
+"class_ogre_1_1_camera.html#a2e308ef3ce0afb4e715144a9b9460a13":[5,0,9,2,32],
+"class_ogre_1_1_camera.html#a30cd8360e8f1885f537f6185b621c406":[5,0,9,2,25],
+"class_ogre_1_1_camera.html#a311f3f06799fc4ba14a233406e25503f":[5,0,9,2,3],
+"class_ogre_1_1_camera.html#a317d01327cfaaee9fd2b8cdc93c68f57":[5,0,9,2,76],
+"class_ogre_1_1_camera.html#a3436778d5472fbb52b695278805456fb":[5,0,9,2,21],
+"class_ogre_1_1_camera.html#a37cd34e25032c16baf7cdd4d46f66511":[5,0,9,2,73],
+"class_ogre_1_1_camera.html#a401200010bd5c1441006f03564f74e22":[5,0,9,2,65],
+"class_ogre_1_1_camera.html#a40785781854c0ef26b7ee2ac064bd601":[5,0,9,2,48],
+"class_ogre_1_1_camera.html#a4225c2dfc17536d140579052816c7b76":[5,0,9,2,53],
 "class_ogre_1_1_camera.html#a438a713ce67e915836d7952bf5b572f9":[5,0,9,2,62],
 "class_ogre_1_1_camera.html#a4808eec2a7c9b8d56ad1961b6a46a2b8":[5,0,9,2,87],
 "class_ogre_1_1_camera.html#a49b7b8fe85de280b70c012f8416fab6e":[5,0,9,2,40],
@@ -238,16 +249,5 @@ var NAVTREEINDEX8 =
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_green_adjust.html":[5,2,10,2,2],
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_green_adjust.html#a52a87097b5e7433fb1f2550a3af0d74f":[5,2,10,2,2,0],
 "class_ogre_1_1_colour_fader_affector_1_1_cmd_green_adjust.html#a7557ad094802da0b98c88e4ba63b0c5b":[5,2,10,2,2,1],
-"class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html":[5,2,10,2,3],
-"class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#a5cff5fba3863440b627ba6d37b426102":[5,2,10,2,3,0],
-"class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#ab16251011e251ead9f7ced8e33ac03ca":[5,2,10,2,3,1],
-"class_ogre_1_1_colour_image_affector.html":[6,0,1,62],
-"class_ogre_1_1_colour_image_affector.html":[7,0,0,62],
-"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[6,0,1,62,6],
-"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[7,0,0,62,6],
-"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[6,0,1,62,4],
-"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[7,0,0,62,4],
-"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[6,0,1,62,5],
-"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[7,0,0,62,5],
-"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[6,0,1,62,1]
+"class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html":[5,2,10,2,3]
 };
