@@ -1,5 +1,16 @@
 var NAVTREEINDEX9 =
 {
+"class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#a5cff5fba3863440b627ba6d37b426102":[5,2,10,2,3,0],
+"class_ogre_1_1_colour_fader_affector_1_1_cmd_red_adjust.html#ab16251011e251ead9f7ced8e33ac03ca":[5,2,10,2,3,1],
+"class_ogre_1_1_colour_image_affector.html":[6,0,1,62],
+"class_ogre_1_1_colour_image_affector.html":[7,0,0,62],
+"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[6,0,1,62,6],
+"class_ogre_1_1_colour_image_affector.html#a1f75f89834ef18b62b909b4682e6a812":[7,0,0,62,6],
+"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[6,0,1,62,4],
+"class_ogre_1_1_colour_image_affector.html#a2fb5b54b08efe8a456d4e57dfa7860d4":[7,0,0,62,4],
+"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[6,0,1,62,5],
+"class_ogre_1_1_colour_image_affector.html#a52df9990e8c3cdeda702bcefc77f67d6":[7,0,0,62,5],
+"class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[6,0,1,62,1],
 "class_ogre_1_1_colour_image_affector.html#a7118e0cf5c7cefcbbf004580add48ae5":[7,0,0,62,1],
 "class_ogre_1_1_colour_image_affector.html#a712aea5134dc25d81d92a0f8d217859f":[6,0,1,62,2],
 "class_ogre_1_1_colour_image_affector.html#a712aea5134dc25d81d92a0f8d217859f":[7,0,0,62,2],
@@ -48,50 +59,51 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#ab7927db974a724cdd9798e597a398c7f":[6,0,1,63,1,1],
 "class_ogre_1_1_colour_interpolator_affector_1_1_cmd_time_adjust.html#ab7927db974a724cdd9798e597a398c7f":[7,0,0,63,1,1],
 "class_ogre_1_1_colour_value.html":[5,0,2,5],
-"class_ogre_1_1_colour_value.html#a0b3c6d7aba3e2879c5bff3d864241584":[5,0,2,5,34],
-"class_ogre_1_1_colour_value.html#a0f66d1fae35f9f2a13ce26349fb71a79":[5,0,2,5,35],
-"class_ogre_1_1_colour_value.html#a11c1455b2d4bc0bb0fc4fb20ba6fa099":[5,0,2,5,30],
-"class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07":[5,0,2,5,41],
-"class_ogre_1_1_colour_value.html#a1570846ab08c04adbd3d58cd2aa1c860":[5,0,2,5,16],
+"class_ogre_1_1_colour_value.html#a0b3c6d7aba3e2879c5bff3d864241584":[5,0,2,5,35],
+"class_ogre_1_1_colour_value.html#a0f66d1fae35f9f2a13ce26349fb71a79":[5,0,2,5,36],
+"class_ogre_1_1_colour_value.html#a11c1455b2d4bc0bb0fc4fb20ba6fa099":[5,0,2,5,31],
+"class_ogre_1_1_colour_value.html#a13fbd050af26b8bd549ccb46aa699e07":[5,0,2,5,42],
+"class_ogre_1_1_colour_value.html#a1570846ab08c04adbd3d58cd2aa1c860":[5,0,2,5,17],
 "class_ogre_1_1_colour_value.html#a170729634175d1cea8bd8c882bdde71e":[5,0,2,5,6],
-"class_ogre_1_1_colour_value.html#a176de8fc97c2f6392b585830286dfe49":[5,0,2,5,27],
-"class_ogre_1_1_colour_value.html#a1bcb3611eec7ec5ce68967e6023acb6d":[5,0,2,5,37],
+"class_ogre_1_1_colour_value.html#a176de8fc97c2f6392b585830286dfe49":[5,0,2,5,28],
+"class_ogre_1_1_colour_value.html#a1bcb3611eec7ec5ce68967e6023acb6d":[5,0,2,5,38],
 "class_ogre_1_1_colour_value.html#a1cf6b673afb17fe889e4255a938c3cbb":[5,0,2,5,7],
 "class_ogre_1_1_colour_value.html#a21875c1d92c3ad0cba9cafd5776f42a0":[5,0,2,5,13],
 "class_ogre_1_1_colour_value.html#a27b26fbfa1098376c47e337192d04f27":[5,0,2,5,5],
 "class_ogre_1_1_colour_value.html#a3595487122e676dae5786151b169e213":[5,0,2,5,10],
-"class_ogre_1_1_colour_value.html#a39d844917c84da6568f4486eb4011eea":[5,0,2,5,17],
-"class_ogre_1_1_colour_value.html#a435d20368c31728dea21469d1db036f6":[5,0,2,5,23],
+"class_ogre_1_1_colour_value.html#a39d844917c84da6568f4486eb4011eea":[5,0,2,5,18],
+"class_ogre_1_1_colour_value.html#a435d20368c31728dea21469d1db036f6":[5,0,2,5,24],
 "class_ogre_1_1_colour_value.html#a438810466e8d1c29eb6b84f372ceb2e7":[5,0,2,5,4],
 "class_ogre_1_1_colour_value.html#a4825d1fb89ea5aae7f2e18e108aa7f23":[5,0,2,5,3],
-"class_ogre_1_1_colour_value.html#a4b5005bc7a691be69292a06fdab037fd":[5,0,2,5,38],
+"class_ogre_1_1_colour_value.html#a4b5005bc7a691be69292a06fdab037fd":[5,0,2,5,39],
 "class_ogre_1_1_colour_value.html#a5605ea48f88f611955bdd0c96150a8e5":[5,0,2,5,8],
-"class_ogre_1_1_colour_value.html#a5b0ed5d4289ec1f56295380a0a334e4f":[5,0,2,5,32],
-"class_ogre_1_1_colour_value.html#a6141ef6c5e433c9e59807222f7fa79fe":[5,0,2,5,33],
-"class_ogre_1_1_colour_value.html#a6e086633637e335238d517e0ec9f2cd2":[5,0,2,5,40],
+"class_ogre_1_1_colour_value.html#a5b0ed5d4289ec1f56295380a0a334e4f":[5,0,2,5,33],
+"class_ogre_1_1_colour_value.html#a6141ef6c5e433c9e59807222f7fa79fe":[5,0,2,5,34],
+"class_ogre_1_1_colour_value.html#a6e086633637e335238d517e0ec9f2cd2":[5,0,2,5,41],
 "class_ogre_1_1_colour_value.html#a783132a039d3d5bbccedbcea77ff3c79":[5,0,2,5,0],
-"class_ogre_1_1_colour_value.html#a788549742c1f030184c53008423c7b9c":[5,0,2,5,21],
+"class_ogre_1_1_colour_value.html#a788549742c1f030184c53008423c7b9c":[5,0,2,5,22],
 "class_ogre_1_1_colour_value.html#a7c80a19ac61f97f217d5b39d8f1dd39b":[5,0,2,5,2],
 "class_ogre_1_1_colour_value.html#a7ced6ef07e9a1e6de8ea50ef824ed9b1":[5,0,2,5,12],
-"class_ogre_1_1_colour_value.html#a7f38270891b9602c9951fe0d0a720311":[5,0,2,5,28],
+"class_ogre_1_1_colour_value.html#a7f38270891b9602c9951fe0d0a720311":[5,0,2,5,29],
 "class_ogre_1_1_colour_value.html#a7f86f695818890ba2f857618b1af9f59":[5,0,2,5,11],
-"class_ogre_1_1_colour_value.html#a8242cd224705e15b9e1533fe83c290c7":[5,0,2,5,18],
-"class_ogre_1_1_colour_value.html#a854058a76927880ae345ac1c465f9713":[5,0,2,5,43],
-"class_ogre_1_1_colour_value.html#a8638135228e5ddcd1dc7db320542cf72":[5,0,2,5,19],
-"class_ogre_1_1_colour_value.html#a8bf64c97ca14f64127cb3f5f95e856cf":[5,0,2,5,22],
+"class_ogre_1_1_colour_value.html#a8242cd224705e15b9e1533fe83c290c7":[5,0,2,5,19],
+"class_ogre_1_1_colour_value.html#a854058a76927880ae345ac1c465f9713":[5,0,2,5,44],
+"class_ogre_1_1_colour_value.html#a8638135228e5ddcd1dc7db320542cf72":[5,0,2,5,20],
+"class_ogre_1_1_colour_value.html#a8bf64c97ca14f64127cb3f5f95e856cf":[5,0,2,5,23],
+"class_ogre_1_1_colour_value.html#a8c556536b34322c92f0f0b527a11b603":[5,0,2,5,15],
 "class_ogre_1_1_colour_value.html#aa807f795d563dbf32601b20925cd46d4":[5,0,2,5,1],
 "class_ogre_1_1_colour_value.html#aa8bbc191b3de291abe02fce7e0d619c2":[5,0,2,5,14],
-"class_ogre_1_1_colour_value.html#aabc748c7dbf62da85d6016c073314e7b":[5,0,2,5,39],
-"class_ogre_1_1_colour_value.html#aae078d77b654f76e3b760174f93474ec":[5,0,2,5,42],
+"class_ogre_1_1_colour_value.html#aabc748c7dbf62da85d6016c073314e7b":[5,0,2,5,40],
+"class_ogre_1_1_colour_value.html#aae078d77b654f76e3b760174f93474ec":[5,0,2,5,43],
 "class_ogre_1_1_colour_value.html#aaf5cc43741699cd3c0c7e81a1dc349a2":[5,0,2,5,9],
-"class_ogre_1_1_colour_value.html#ab67f75eb63c2ee10cb6e874219b01b67":[5,0,2,5,36],
-"class_ogre_1_1_colour_value.html#ac8e68543a87fcc6e1c0789c052fa45ba":[5,0,2,5,15],
-"class_ogre_1_1_colour_value.html#ad33e4ae6c7e6d223545613c4991c91ed":[5,0,2,5,24],
-"class_ogre_1_1_colour_value.html#ad46a3cf5b7e9781aaee892d23458ebd0":[5,0,2,5,26],
-"class_ogre_1_1_colour_value.html#adcc45721a4be58eafb2a3bb6df4f73b2":[5,0,2,5,25],
-"class_ogre_1_1_colour_value.html#ae256d6a81e87d0f33a0c27c10d6b78f6":[5,0,2,5,29],
-"class_ogre_1_1_colour_value.html#ae493dc97ca571117a5709088d1494bde":[5,0,2,5,20],
-"class_ogre_1_1_colour_value.html#af9df6a8c10f290187bc051c6ee61863f":[5,0,2,5,31],
+"class_ogre_1_1_colour_value.html#ab67f75eb63c2ee10cb6e874219b01b67":[5,0,2,5,37],
+"class_ogre_1_1_colour_value.html#ac8e68543a87fcc6e1c0789c052fa45ba":[5,0,2,5,16],
+"class_ogre_1_1_colour_value.html#ad33e4ae6c7e6d223545613c4991c91ed":[5,0,2,5,25],
+"class_ogre_1_1_colour_value.html#ad46a3cf5b7e9781aaee892d23458ebd0":[5,0,2,5,27],
+"class_ogre_1_1_colour_value.html#adcc45721a4be58eafb2a3bb6df4f73b2":[5,0,2,5,26],
+"class_ogre_1_1_colour_value.html#ae256d6a81e87d0f33a0c27c10d6b78f6":[5,0,2,5,30],
+"class_ogre_1_1_colour_value.html#ae493dc97ca571117a5709088d1494bde":[5,0,2,5,21],
+"class_ogre_1_1_colour_value.html#af9df6a8c10f290187bc051c6ee61863f":[5,0,2,5,32],
 "class_ogre_1_1_composition_pass.html":[5,0,1,5],
 "class_ogre_1_1_composition_pass.html#a052e16876215e11e03bcba8657faf917":[5,0,1,5,33],
 "class_ogre_1_1_composition_pass.html#a05cbca68fbc408dbf755612cfb72707d":[5,0,1,5,47],
@@ -237,17 +249,5 @@ var NAVTREEINDEX9 =
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a7e371a5590972522e7f8024295bb8a59":[5,0,1,7,0,0],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a8826739f93ea3bb356c4a1bb5b5b008c":[5,0,1,7,0,15],
 "class_ogre_1_1_composition_technique_1_1_texture_definition.html#a90341172974dbdea53d010c4d5aa90da":[5,0,1,7,0,14],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a961b6a77bc1f93094da60c68ce7124f6":[5,0,1,7,0,6],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a99163323a7ab7d6b661f538b17c8f97b":[5,0,1,7,0,9],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#aa9c8a54bdaa418233c6f10c3a8a2eb98":[5,0,1,7,0,13],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#abbbb4c6b2ea75b413ff5534be536ad73":[5,0,1,7,0,5],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#acdc503bc2adeee31d32988c6c994c0d6":[5,0,1,7,0,10],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#ae59f6efc2a9d0bc5cf539c647351848d":[5,0,1,7,0,2],
-"class_ogre_1_1_composition_technique_1_1_texture_definition.html#af7cf8abd5790419f08b59519b3bb3374":[5,0,1,7,0,11],
-"class_ogre_1_1_compositor.html":[5,0,1,8],
-"class_ogre_1_1_compositor.html#a1f3a6209ce89a4105719c26e0b2a5f46":[5,0,1,8,2],
-"class_ogre_1_1_compositor.html#a34a3a5086152382d77a85c25fbabb1be":[5,0,1,8,0],
-"class_ogre_1_1_compositor.html#a446dd4a5fed791283a79d6acd9936d55":[5,0,1,8,15],
-"class_ogre_1_1_compositor.html#a52653a85d40ae889556707320a784d3e":[5,0,1,8,12],
-"class_ogre_1_1_compositor.html#a57a6ab020e5ac812bb96aa59b1497fbd":[5,0,1,8,8]
+"class_ogre_1_1_composition_technique_1_1_texture_definition.html#a961b6a77bc1f93094da60c68ce7124f6":[5,0,1,7,0,6]
 };
