@@ -8,5 +8,6 @@ var union_ogre_bites_1_1_event =
     [ "tfinger", "union_ogre_bites_1_1_event.html#adb1cee81610d1700eef37fa281ea14e3", null ],
     [ "text", "union_ogre_bites_1_1_event.html#afe98c3cbfefeec08de511d16d5dd624e", null ],
     [ "axis", "union_ogre_bites_1_1_event.html#a4580f722360bd8b75b1c6ddffbcbeada", null ],
-    [ "cbutton", "union_ogre_bites_1_1_event.html#ac645626194defe49c109be496494deae", null ]
+    [ "cbutton", "union_ogre_bites_1_1_event.html#ac645626194defe49c109be496494deae", null ],
+    [ "hat", "union_ogre_bites_1_1_event.html#a331469d3f5cbdec546304908c29e1749", null ]
 ];
\ No newline at end of file
